"""
Authors: Peter Mawhorter
Consulted:
Date: 2022-11-09
Purpose: Rewrites testing files so that any accidental alterations to
    them get reset and everything is ready for the tests to run.
"""

ERASE = [
    'onlyEvents-nobody.txt',
    'onlyEvents-numbers.txt',
    'onlyEvents-youMe.txt',
    'onlyEvents-forest.txt',
    'listSenders-nobody.txt',
    'listSenders-numbers.txt',
    'listSenders-youMe.txt',
    'listSenders-forest.txt',
    'messagesWithWord-nobody.txt',
    'messagesWithWord-numbers-hey.txt',
    'messagesWithWord-numbers-seven.txt',
    'messagesWithWord-numbers-aaah.txt',
    'messagesWithWord-youMe-hey.txt',
    'messagesWithWord-forest-BARK.txt',
    'messagesWithWord-forest-caw.txt',
    'messagesWithWord-forest-A.txt',
    'messagesFromUser-nobody.txt',
    'messagesFromUser-numbers-one.txt',
    'messagesFromUser-numbers-two.txt',
    'messagesFromUser-numbers-eight.txt',
    'messagesFromUser-youMe-you.txt',
    'messagesFromUser-youMe-me.txt',
    'messagesFromUser-youMe-greatPerson632.txt',
    'messagesFromUser-youMe-nobody.txt',
    'messagesFromUser-forest-squirrel.txt',
    'messagesFromUser-forest-snail.txt',
]

CONTENTS = {
    'nobody.txt': '''\
nobody has joined the chatroom
nobody has left the chatroom
''',

    'numbers.txt': '''\
one: hi
two: hello
three: what's up?
four: hey
five: how's it going?
six: hey, um, ...I'm afraid of seven
seven: mmmm crunch crunch this digit is delicious
eight: aaah :(
''',

    'youMe.txt': '''\
you has joined the chatroom
me has joined the chatroom
me: Hi!
you: Bye~
you has left the chatroom
you has joined the chatroom
you: hey
you: hey!
you: hey listen!
me: whaaaat?
you: we're in an example!
me has left the chatroom
me has joined the chatroom
you: it's an example!
me: hooooray! ^.^;
greatPerson632 has entered the chatroom
you: isn't this great?
me: um... sure, I guess it's great.
me has left the chatroom
greatPerson632: YES, IT IS GREAT.
you has left the chatroom
greatPerson632 has left the chatroom
''',

    'forest.txt': '''\
squirrel has joined the chatroom
crow has joined the chatroom
snail has joined the chatroom
squirrel: chatter chatter
crow: CAW
dog has joined the chatroom
dog: BARK BARK BARK
squirrel runs up a tree
squirrel: chatter chatter
dog: BARK BARK BARK, BARK!
dog wags his tail excitedly
deer has entered the chatroom
dog: BARKBARKBARKBARK
dog chases deer
deer: WTF?!?
deer has left the chatroom
dog has left the chatroom
squirrel: chatter chatter
squirrel has left the chatroom
crow: CAW, CAW
crow has left the chatroom
...
snail has left the chatroom
''',
}


def resetFiles():
    """
    Overwrites all testing files, resetting them to be ready for running
    tests. Also erases the contents of all files in the `ERASE` list to
    ensure that stale output doesn't accidentally let a test pass.
    """
    for filename in CONTENTS:
        with open(filename, 'w') as fileOutput:
            fileOutput.write(CONTENTS[filename])

    for filename in ERASE:
        with open(filename, 'w') as fileOutput:
            fileOutput.write('')


def reportFileChanges():
    """
    Returns None if all files are unaltered, and otherwise returns a
    string describing which file(s) were changed.
    """
    messages = []
    for filename in CONTENTS:
        with open(filename, 'r') as fileInput:
            if fileInput.read() != CONTENTS[filename]:
                messages.appned(f"File '{filename}' has been changed!")

    if len(messages) == 0:
        return None
    else:
        return '\n'.join(messages)


# This will run the resetFiles function if you run this as a file, but
# not when you import it.
if __name__ == "__main__":
    resetFiles()
