"""
Authors: Peter Mawhorter
Consulted:
Date: 2022-11-09
Purpose: Testing file for transcriptManager project testing file I/O
    skills.
"""

import optimism

import transcriptManager

import resetFiles

resetFiles.resetFiles()
tester = optimism.testFunctionMaybe(transcriptManager, "onlyEvents")

case1 = tester.case('nobody.txt', 'onlyEvents-nobody.txt')
case1.checkFileLines(
    'onlyEvents-nobody.txt',
    'nobody has joined the chatroom',
    'nobody has left the chatroom'
)

case2 = tester.case("numbers.txt", 'onlyEvents-numbers.txt')
case2.checkFileLines('onlyEvents-numbers.txt', '')

case3 = tester.case("youMe.txt", 'onlyEvents-youMe.txt')
case3.checkFileLines(
    'onlyEvents-youMe.txt',
    "you has joined the chatroom",
    "me has joined the chatroom",
    "you has left the chatroom",
    "you has joined the chatroom",
    "me has left the chatroom",
    "me has joined the chatroom",
    "greatPerson632 has entered the chatroom",
    "me has left the chatroom",
    "you has left the chatroom",
    "greatPerson632 has left the chatroom"
)

case4 = tester.case("forest.txt", 'onlyEvents-forest.txt')
case4.checkFileLines(
    'onlyEvents-forest.txt',
    "squirrel has joined the chatroom",
    "crow has joined the chatroom",
    "snail has joined the chatroom",
    "dog has joined the chatroom",
    "squirrel runs up a tree",
    "dog wags his tail excitedly",
    "deer has entered the chatroom",
    "dog chases deer",
    "deer has left the chatroom",
    "dog has left the chatroom",
    "squirrel has left the chatroom",
    "crow has left the chatroom",
    "...",
    "snail has left the chatroom"
)

optimism.expect(resetFiles.reportFileChanges(), None)
resetFiles.resetFiles()
tester = optimism.testFunctionMaybe(transcriptManager, "listSenders")

case1 = tester.case('nobody.txt', 'listSenders-nobody.txt')
case1.checkFileLines('listSenders-nobody.txt', '')

case2 = tester.case('numbers.txt', 'listSenders-numbers.txt')
case2.checkFileLines(
    'listSenders-numbers.txt',
    'one',
    'two',
    'three',
    'four',
    'five',
    'six',
    'seven',
    'eight',
)

case3 = tester.case('youMe.txt', 'listSenders-youMe.txt')
case3.checkFileLines(
    'listSenders-youMe.txt',
    'me',
    'you',
    'greatPerson632',
)

case4 = tester.case('forest.txt', 'listSenders-forest.txt')
case4.checkFileLines(
    'listSenders-forest.txt',
    'squirrel',
    'crow',
    'dog',
    'deer'
) # note that snail never says anything


optimism.expect(resetFiles.reportFileChanges(), None)
resetFiles.resetFiles()
tester = optimism.testFunctionMaybe(transcriptManager, "messagesWithWord")

case1 = tester.case('nobody.txt', 'any', 'messagesWithWord-nobody.txt')
case1.checkFileLines('messagesWithWord-nobody.txt', '')

case2 = tester.case('numbers.txt', 'hey', 'messagesWithWord-numbers-hey.txt')
case2.checkFileLines(
    'messagesWithWord-numbers-hey.txt',
    "four: hey",
    "six: hey, um, ...I'm afraid of seven",
)

case3 = tester.case(
    'numbers.txt',
    'seven',
    'messagesWithWord-numbers-seven.txt'
)
case3.checkFileLines(
    'messagesWithWord-numbers-seven.txt',
    "six: hey, um, ...I'm afraid of seven",
) # note that the message by user 'seven' is not included

case4 = tester.case(
    'numbers.txt',
    'aaah',
    'messagesWithWord-numbers-aaah.txt'
)
case4.checkFileLines(
    'messagesWithWord-numbers-aaah.txt',
    "eight: aaah :("
)

case5 = tester.case('youMe.txt', 'hey', 'messagesWithWord-youMe-hey.txt')
case5.checkFileLines(
    'messagesWithWord-youMe-hey.txt',
    "you: hey",
    "you: hey!",
    "you: hey listen!"
)

case6 = tester.case('forest.txt', 'BARK', 'messagesWithWord-forest-BARK.txt')
case6.checkFileLines(
    'messagesWithWord-forest-BARK.txt',
    "dog: BARK BARK BARK",
    "dog: BARK BARK BARK, BARK!",
    "dog: BARKBARKBARKBARK"
)

case7 = tester.case('forest.txt', 'caw', 'messagesWithWord-forest-caw.txt')
case7.checkFileLines(
    'messagesWithWord-forest-caw.txt',
    "crow: CAW",
    "crow: CAW, CAW"
)

case8 = tester.case('forest.txt', 'A', 'messagesWithWord-forest-A.txt')
case8.checkFileLines(
    'messagesWithWord-forest-A.txt',
    "squirrel: chatter chatter",
    "crow: CAW",
    "dog: BARK BARK BARK",
    "squirrel: chatter chatter",
    "dog: BARK BARK BARK, BARK!",
    "dog: BARKBARKBARKBARK",
    "squirrel: chatter chatter",
    "crow: CAW, CAW"
)

optimism.expect(resetFiles.reportFileChanges(), None)
resetFiles.resetFiles()
tester = optimism.testFunctionMaybe(transcriptManager, "messagesFromUser")

case1 = tester.case('nobody.txt', 'nobody', 'messagesFromUser-nobody.txt')
case1.checkFileLines('messagesFromUser-nobody.txt', '')

case2 = tester.case('numbers.txt', 'one', 'messagesFromUser-numbers-one.txt')
case2.checkFileLines('messagesFromUser-numbers-one.txt', "hi")

case3 = tester.case('numbers.txt', 'two', 'messagesFromUser-numbers-two.txt')
case3.checkFileLines('messagesFromUser-numbers-two.txt', "hello")

case3 = tester.case(
    'numbers.txt',
    'eight',
    'messagesFromUser-numbers-eight.txt'
)
case3.checkFileLines(
    'messagesFromUser-numbers-eight.txt',
    "aaah :("
)

case4 = tester.case('youMe.txt', 'you', 'messagesFromUser-youMe-you.txt')
case4.checkFileLines(
    'messagesFromUser-youMe-you.txt',
    "Bye~",
    "hey",
    "hey!",
    "hey listen!",
    "we're in an example!",
    "it's an example!",
    "isn't this great?"
)

case5 = tester.case('youMe.txt', 'me', 'messagesFromUser-youMe-me.txt')
case5.checkFileLines(
    'messagesFromUser-youMe-me.txt',
    "Hi!",
    "whaaaat?",
    "hooooray! ^.^;",
    "um... sure, I guess it's great.",
)

case6 = tester.case(
    'youMe.txt',
    'greatPerson632',
    'messagesFromUser-youMe-greatPerson632.txt'
)
case6.checkFileLines(
    'messagesFromUser-youMe-greatPerson632.txt',
    "YES, IT IS GREAT."
)

case6 = tester.case('youMe.txt', 'nobody', 'messagesFromUser-youMe-nobody.txt')
case6.checkFileLines('messagesFromUser-youMe-nobody.txt', '')

case7 = tester.case(
    'forest.txt',
    'squirrel',
    'messagesFromUser-forest-squirrel.txt'
)
case7.checkFileLines(
    'messagesFromUser-forest-squirrel.txt',
    "chatter chatter",
    "chatter chatter",
    "chatter chatter"
)

case8 = tester.case('forest.txt', 'snail', 'messagesFromUser-forest-snail.txt')
case8.checkFileLines('messagesFromUser-forest-snail.txt', '')
